@@ -29,7 +29,7 @@ COUNTRIES = (
     ('BM', _(u'Bermuda')),
     ('BT', _(u'Bhutan')),
     ('BO', _(u'Bolivia, Plurinational State of')),
-    ('BQ', _(u'Bonaire, Saint Eustatius and Saba')),
+    ('BQ', _(u'Bonaire, Sint Eustatius and Saba')),
     ('BA', _(u'Bosnia and Herzegovina')),
     ('BW', _(u'Botswana')),
     ('BV', _(u'Bouvet Island')),
@@ -209,6 +209,7 @@ COUNTRIES = (
     ('SO', _(u'Somalia')),
     ('ZA', _(u'South Africa')),
     ('GS', _(u'South Georgia and the South Sandwich Islands')),
+    ('SS', _(u'South Sudan')),
     ('ES', _(u'Spain')),
     ('LK', _(u'Sri Lanka')),
     ('SD', _(u'Sudan')),
@@ -284,7 +285,7 @@ COUNTRIES_PLUS = (
     ('BT', _(u'Bhutan')),
     ('VE', _(u'Bolivarian Republic of Venezuela')),
     ('BO', _(u'Bolivia, Plurinational State of')),
-    ('BQ', _(u'Bonaire, Saint Eustatius and Saba')),
+    ('BQ', _(u'Bonaire, Sint Eustatius and Saba')),
     ('BA', _(u'Bosnia and Herzegovina')),
     ('BW', _(u'Botswana')),
     ('BV', _(u'Bouvet Island')),
@@ -451,7 +452,6 @@ COUNTRIES_PLUS = (
     ('RU', _(u'Russian Federation')),
     ('RW', _(u'Rwanda')),
     ('BL', _(u'Saint Barth\xe9lemy')),
-    ('BQ', _(u'Saint Eustatius and Saba Bonaire')),
     ('SH', _(u'Saint Helena, Ascension and Tristan Da Cunha')),
     ('KN', _(u'Saint Kitts and Nevis')),
     ('LC', _(u'Saint Lucia')),
@@ -467,6 +467,7 @@ COUNTRIES_PLUS = (
     ('SC', _(u'Seychelles')),
     ('SL', _(u'Sierra Leone')),
     ('SG', _(u'Singapore')),
+    ('BQ', _(u'Sint Eustatius and Saba Bonaire')),
     ('SX', _(u'Sint Maarten (Dutch Part)')),
     ('SK', _(u'Slovakia')),
     ('SI', _(u'Slovenia')),
@@ -474,6 +475,7 @@ COUNTRIES_PLUS = (
     ('SO', _(u'Somalia')),
     ('ZA', _(u'South Africa')),
     ('GS', _(u'South Georgia and the South Sandwich Islands')),
+    ('SS', _(u'South Sudan')),
     ('ES', _(u'Spain')),
     ('LK', _(u'Sri Lanka')),
     ('SD', _(u'Sudan')),
@@ -550,7 +552,7 @@ OFFICIAL_COUNTRIES = {
     'BM': u'BERMUDA',
     'BT': u'BHUTAN',
     'BO': u'BOLIVIA, PLURINATIONAL STATE OF',
-    'BQ': u'BONAIRE, SAINT EUSTATIUS AND SABA',
+    'BQ': u'BONAIRE, SINT EUSTATIUS AND SABA',
     'BA': u'BOSNIA AND HERZEGOVINA',
     'BW': u'BOTSWANA',
     'BV': u'BOUVET ISLAND',
@@ -730,6 +732,7 @@ OFFICIAL_COUNTRIES = {
     'SO': u'SOMALIA',
     'ZA': u'SOUTH AFRICA',
     'GS': u'SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS',
+    'SS': u'SOUTH SUDAN',
     'ES': u'SPAIN',
     'LK': u'SRI LANKA',
     'SD': u'SUDAN',
